Class: LWS::Auth::Token

Inherits:
Generic::Model show all
Defined in:
lib/lws/apps/auth.rb

Overview

The token class

Instance Attribute Summary collapse

Attributes inherited from Generic::Model

#created_at, #id, #updated_at, #url, #url_html

Method Summary

Methods inherited from Generic::Model

#deep_dup, #dig, #reload, #rollback, #save

Instance Attribute Details

#accountAccount



375
# File 'lib/lws/apps/auth.rb', line 375

belongs_to :account, uri: nil

#account_idInteger



379
# File 'lib/lws/apps/auth.rb', line 379

attribute :account_id

#created_onObject (readonly)

Deprecated.

This is an old alias of Generic::Model#created_at.



393
# File 'lib/lws/apps/auth.rb', line 393

attribute :created_on

#deviceDevice?

Note:

Each token is associated to either a user or a device.

Returns the device the token belongs to.



384
# File 'lib/lws/apps/auth.rb', line 384

belongs_to :device, uri: nil

#device_idInteger?



388
# File 'lib/lws/apps/auth.rb', line 388

attribute :device_id

#expires_onString



397
# File 'lib/lws/apps/auth.rb', line 397

attribute :expires_on

#ip_addressString



401
# File 'lib/lws/apps/auth.rb', line 401

attribute :ip_address

#nameString?



405
# File 'lib/lws/apps/auth.rb', line 405

attribute :name

#tokenString



409
# File 'lib/lws/apps/auth.rb', line 409

attribute :token

#used_onString?



413
# File 'lib/lws/apps/auth.rb', line 413

attribute :used_on

#userUser?

Note:

Each token is associated to either a user or a device.

Returns the user the token belongs to.



423
# File 'lib/lws/apps/auth.rb', line 423

belongs_to :user, uri: nil

#user_agentString?



418
# File 'lib/lws/apps/auth.rb', line 418

attribute :user_agent

#user_idInteger?



427
# File 'lib/lws/apps/auth.rb', line 427

attribute :user_id