Class: LWS::DigitalSignage::Layout::Element::Customizable

Inherits:
Generic::Model
  • Object
show all
Defined in:
lib/lws/apps/digital_signage.rb

Overview

Note:

This class is only used within the context of the LWS::DigitalSignage::Layout::Element class.

The layout element customizable class

Instance Attribute Summary collapse

Attributes inherited from Generic::Model

#created_at, #id, #updated_at, #url, #url_html

Method Summary

Methods inherited from Generic::Model

#deep_dup, #dig, #reload, #rollback, #save

Instance Attribute Details

#attrString



815
# File 'lib/lws/apps/digital_signage.rb', line 815

attribute :attr

#descriptionString



819
# File 'lib/lws/apps/digital_signage.rb', line 819

attribute :description

#elementLayout::element



824
# File 'lib/lws/apps/digital_signage.rb', line 824

belongs_to :element, class_name: "LWS::DigitalSignage::Layout::Element"

#element_idInteger



828
# File 'lib/lws/apps/digital_signage.rb', line 828

attribute :element_id

#helpString



832
# File 'lib/lws/apps/digital_signage.rb', line 832

attribute :help

#placeholderString



836
# File 'lib/lws/apps/digital_signage.rb', line 836

attribute :placeholder

#presetsArray<Hash{String => String}>

This is a list of mappings of the preset label (key “label”) to the preset value (key “value”).



843
# File 'lib/lws/apps/digital_signage.rb', line 843

attribute :presets

#requiredString



847
# File 'lib/lws/apps/digital_signage.rb', line 847

attribute :required

#titleString



851
# File 'lib/lws/apps/digital_signage.rb', line 851

attribute :title

#uuidString



855
# File 'lib/lws/apps/digital_signage.rb', line 855

attribute :uuid