Class: LWS::DigitalSignage::Layout::Version

Inherits:
Generic::Model
  • Object
show all
Defined in:
lib/lws/apps/digital_signage.rb

Overview

Note:

This class is only used within the context of the LWS::DigitalSignage::Layout class.

The layout version class

Instance Attribute Summary collapse

Attributes inherited from Generic::Model

#created_at, #id, #updated_at, #url, #url_html

Method Summary

Methods inherited from Generic::Model

#deep_dup, #dig, #reload, #rollback, #save

Instance Attribute Details

#archive_storage_idString?



898
# File 'lib/lws/apps/digital_signage.rb', line 898

attribute :archive_storage_id

#archive_urlString?

Note:

To be able retrieve the archive, the token needs to be passed via X-Token in the HTTP request headers!

Note:

This attribute is only available if the token is of an account with sysadmin permissions

Returns the URL of the archive/layout pack of the layout version (if accessible).



908
# File 'lib/lws/apps/digital_signage.rb', line 908

attribute :archive_url

#element_idsArray<Integer>



913
# File 'lib/lws/apps/digital_signage.rb', line 913

attribute :element_ids

#elementsArray<Layout::Element>



918
# File 'lib/lws/apps/digital_signage.rb', line 918

has_many :elements, class_name: "LWS::DigitalSignage::Layout::Element"

#heightInteger



922
# File 'lib/lws/apps/digital_signage.rb', line 922

attribute :width

#layoutLayout



926
# File 'lib/lws/apps/digital_signage.rb', line 926

belongs_to :layout

#layout_idInteger



930
# File 'lib/lws/apps/digital_signage.rb', line 930

attribute :layout_id

#rotation"landscape", "portrait"



935
# File 'lib/lws/apps/digital_signage.rb', line 935

attribute :rotation

#rotation_angle0, 90



939
# File 'lib/lws/apps/digital_signage.rb', line 939

attribute :rotation_angle

#status"initializing", ... (readonly)



944
# File 'lib/lws/apps/digital_signage.rb', line 944

attribute :status

#thumbnail_urlString?



948
# File 'lib/lws/apps/digital_signage.rb', line 948

attribute :thumbnail_url

#widthInteger



952
# File 'lib/lws/apps/digital_signage.rb', line 952

attribute :width