Class: LWS::Resource::Collection::WeatherLocationMetadata

Inherits:
Metadata
  • Object
show all
Defined in:
lib/lws/apps/resource.rb

Overview

The weather location collection metadata class

This represents the metadata of a weather location collection.

Instance Attribute Summary collapse

Instance Attribute Details

#cityString?

Returns the city of the weather location.

Returns:

  • (String, nil)

    the city of the weather location



202
# File 'lib/lws/apps/resource.rb', line 202

property :city

#countryString?

Returns the country of the weather location.

Returns:

  • (String, nil)

    the country of the weather location



206
# File 'lib/lws/apps/resource.rb', line 206

property :country

#descriptionString?

Returns the description of the weather location.

Returns:

  • (String, nil)

    the description of the weather location



210
# File 'lib/lws/apps/resource.rb', line 210

property :description

#feed_urlString?

Returns the URL of the feed of the weather location.

Returns:

  • (String, nil)

    the URL of the feed of the weather location



214
# File 'lib/lws/apps/resource.rb', line 214

property :feed_url

#forecast_interval"daily", "hourly"

Returns whether the forecast is for a specific day or hour.

Returns:

  • ("daily", "hourly")

    whether the forecast is for a specific day or hour



219
# File 'lib/lws/apps/resource.rb', line 219

property :forecast_interval

#kind"open_weather_map", "unknown"

Returns the kind of the weather location.

Returns:

  • ("open_weather_map", "unknown")

    the kind of the weather location



223
# File 'lib/lws/apps/resource.rb', line 223

property :kind

#latFloat?

Returns the latitude of the weather location.

Returns:

  • (Float, nil)

    the latitude of the weather location



227
# File 'lib/lws/apps/resource.rb', line 227

property :lat

Returns the link of the weather location.

Returns:

  • (String)

    the link of the weather location



231
# File 'lib/lws/apps/resource.rb', line 231

property :link

#longFloat?

Returns the longitude of the weather location.

Returns:

  • (Float, nil)

    the longitude of the weather location



235
# File 'lib/lws/apps/resource.rb', line 235

property :long

#nameString

Returns the name of the forecast location.

Returns:

  • (String)

    the name of the forecast location



239
# File 'lib/lws/apps/resource.rb', line 239

property :name

#refresh_intervalInteger

Returns the interval used to refresh the weather location (in seconds).

Returns:

  • (Integer)

    the interval used to refresh the weather location (in seconds)



244
# File 'lib/lws/apps/resource.rb', line 244

property :refresh_interval

#regionString?

Returns the region of the weather location.

Returns:

  • (String, nil)

    the region of the weather location



248
# File 'lib/lws/apps/resource.rb', line 248

property :region

#titleString

Returns the title of the weather location.

Returns:

  • (String)

    the title of the weather location



252
# File 'lib/lws/apps/resource.rb', line 252

property :title

#tokenString?

Returns the token used to refresh the forecasts.

Returns:

  • (String, nil)

    the token used to refresh the forecasts



256
# File 'lib/lws/apps/resource.rb', line 256

property :token