Class: LWS::Resource::Collection

Inherits:
Generic::Model show all
Defined in:
lib/lws/apps/resource.rb

Overview

The collection class

There are two ways to view collections. Either it is viewed as a set of items (see #items), or it is viewed as something that is associated with one or more meta collections that each have specific item objects (see for example #feed, #image, #images, etc.).

Defined Under Namespace

Classes: Config, Feed, Image, Item, Post, Video, Vimeo, WeatherLocation, YouTube

Instance Attribute Summary collapse

Attributes inherited from Generic::Model

#created_at, #id, #updated_at, #url, #url_html

Method Summary

Methods inherited from Generic::Model

#deep_dup, #dig, #reload, #rollback, #save

Instance Attribute Details

#accountLWS::Auth::Account



55
# File 'lib/lws/apps/resource.rb', line 55

belongs_to :account, class_name: "LWS::Auth::Account"

#account_idInteger



60
# File 'lib/lws/apps/resource.rb', line 60

attribute :account_id

#companyLWS::Auth::Company



64
# File 'lib/lws/apps/resource.rb', line 64

belongs_to :company, class_name: "LWS::Auth::Company"

#company_idInteger



68
# File 'lib/lws/apps/resource.rb', line 68

attribute :company_id

#deleted_atString?



72
# File 'lib/lws/apps/resource.rb', line 72

attribute :deleted_at

#descriptionString



76
# File 'lib/lws/apps/resource.rb', line 76

attribute :description

#emailString?



80
# File 'lib/lws/apps/resource.rb', line 80

attribute :email

#folderFolder



84
# File 'lib/lws/apps/resource.rb', line 84

belongs_to :folder

#folder_idInteger



89
# File 'lib/lws/apps/resource.rb', line 89

attribute :folder_id

#item_idsArray<Integer>



94
# File 'lib/lws/apps/resource.rb', line 94

attribute :item_ids

#itemsArray<Collection::Item>

The returned cllection item (sub)class that is determined by the kind of this collection.



102
# File 'lib/lws/apps/resource.rb', line 102

has_many :items, class_name: "LWS::Resource::Collection::Item"

#kind"feed", ...



107
# File 'lib/lws/apps/resource.rb', line 107

attribute :kind

#nameString



111
# File 'lib/lws/apps/resource.rb', line 111

attribute :name

#preview_urlString



115
# File 'lib/lws/apps/resource.rb', line 115

attribute :preview_url

#processingBoolean



120
# File 'lib/lws/apps/resource.rb', line 120

attribute :processing

#uuidString



124
# File 'lib/lws/apps/resource.rb', line 124

attribute :uuid