Class: LWS::Resource::Collection::WeatherLocationMetadata
Overview
The weather location collection metadata class
This represents the metadata of a weather location collection.
Instance Attribute Summary collapse
-
#city ⇒ String?
The city of the weather location.
-
#country ⇒ String?
The country of the weather location.
-
#description ⇒ String?
The description of the weather location.
-
#feed_url ⇒ String?
The URL of the feed of the weather location.
-
#forecast_interval ⇒ "daily", "hourly"
Whether the forecast is for a specific day or hour.
-
#kind ⇒ "open_weather_map", "unknown"
The kind of the weather location.
-
#lat ⇒ Float?
The latitude of the weather location.
-
#link ⇒ String
The link of the weather location.
-
#long ⇒ Float?
The longitude of the weather location.
-
#name ⇒ String
The name of the forecast location.
-
#refresh_interval ⇒ Integer
The interval used to refresh the weather location (in seconds).
-
#region ⇒ String?
The region of the weather location.
-
#title ⇒ String
The title of the weather location.
-
#token ⇒ String?
The token used to refresh the forecasts.
Instance Attribute Details
#city ⇒ String?
Returns the city of the weather location.
202 |
# File 'lib/lws/apps/resource.rb', line 202 property :city |
#country ⇒ String?
Returns the country of the weather location.
206 |
# File 'lib/lws/apps/resource.rb', line 206 property :country |
#description ⇒ String?
Returns the description of the weather location.
210 |
# File 'lib/lws/apps/resource.rb', line 210 property :description |
#feed_url ⇒ String?
Returns the URL of the feed of the weather location.
214 |
# File 'lib/lws/apps/resource.rb', line 214 property :feed_url |
#forecast_interval ⇒ "daily", "hourly"
Returns whether the forecast is for a specific day or hour.
219 |
# File 'lib/lws/apps/resource.rb', line 219 property :forecast_interval |
#kind ⇒ "open_weather_map", "unknown"
Returns the kind of the weather location.
223 |
# File 'lib/lws/apps/resource.rb', line 223 property :kind |
#lat ⇒ Float?
Returns the latitude of the weather location.
227 |
# File 'lib/lws/apps/resource.rb', line 227 property :lat |
#link ⇒ String
Returns the link of the weather location.
231 |
# File 'lib/lws/apps/resource.rb', line 231 property :link |
#long ⇒ Float?
Returns the longitude of the weather location.
235 |
# File 'lib/lws/apps/resource.rb', line 235 property :long |
#name ⇒ String
Returns the name of the forecast location.
239 |
# File 'lib/lws/apps/resource.rb', line 239 property :name |
#refresh_interval ⇒ Integer
Returns the interval used to refresh the weather location (in seconds).
244 |
# File 'lib/lws/apps/resource.rb', line 244 property :refresh_interval |
#region ⇒ String?
Returns the region of the weather location.
248 |
# File 'lib/lws/apps/resource.rb', line 248 property :region |
#title ⇒ String
Returns the title of the weather location.
252 |
# File 'lib/lws/apps/resource.rb', line 252 property :title |
#token ⇒ String?
Returns the token used to refresh the forecasts.
256 |
# File 'lib/lws/apps/resource.rb', line 256 property :token |